@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2021 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,8 +17,10 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
-"Exponential" <- function(d, range = 1, alpha = 1/range, phi = 1.0) {
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
+"Exponential" <- function(d, range = 1, alpha = 1/range, phi = 1.0,
+                          theta=NULL) {
     #
     # Matern covariance function transcribed from Stein's book page 31
     # nu==smoothness==.5, alpha ==  1/range
@@ -26,10 +28,14 @@
     # GeoR parameters map to kappa==smoothness and phi == range
     # to make old code from Fuentes and also the package SEHmodel
     # phi is accepted as the marginal variance of the process (see below)
-    # within fields this parameter is "rho"
+    # within fields this parameter is "sigma"
 
                                         #
     # check for negative distances
+    # theta argument has been depreciated.
+    if( !is.null( theta)){
+        aRange<- theta
+    }
     if (any(d < 0)) 
         stop("distance argument must be nonnegative")
     #
