@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2021 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,11 +17,16 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
-cubic.cov <- function(x1, x2=NULL, theta = 1, C = NA, marginal = FALSE) {
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
+cubic.cov <- function(x1, x2=NULL, aRange = 1, C = NA, marginal = FALSE,
+                      theta=NULL) {
     # comments in Exp.simple.cov for more details about the
     # required parts of this covariance
-    
+    # theta argument has been deopreciated.
+    if( !is.null( theta)){
+        aRange<- theta
+    }
     if (is.matrix(x1)) {
         if (ncol(x1) != 1) {
             stop(" x is a matrix this is a  1-d covariance")
