@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2021 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,11 +17,13 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 sim.spatialProcess<- function(object, xp,  M = 1, 
     verbose = FALSE, ...) {
-        sigma2 <- (object$sigma.MLE.FULL)^2
-        rho <- object$rho.MLE.FULL
+    # important variance parameters estimated from the data  
+        tau2 <- (object$summary["tau"])^2
+        sigma2 <- (object$summary["sigma2"])
         xp<- as.matrix( xp)
     #
     # check for unique rows of  data locations
@@ -29,8 +31,8 @@ sim.spatialProcess<- function(object, xp,  M = 1,
         stop("data locations should be unique")
     }
     #
-    # set up various sizes of arrays
-    m <- nrow(xp)
+    # find sizes of arrays
+    m <- nrow(xp) 
     n<- nrow( object$x)
     N <- length(object$y)
     if (verbose) {
@@ -76,9 +78,9 @@ sim.spatialProcess<- function(object, xp,  M = 1,
     }
     #
     # Sigma is full covariance at the data locations and at prediction points.
-    #
-    
-    Sigma <- rho * do.call(object$cov.function.name, c(object$args, 
+    # not to be confused with the lowercase tau that is the nugget variance
+    # 
+    Sigma <- sigma2 * do.call(object$cov.function.name, c(object$args, 
         list(x1 = xUnique, x2 = xUnique)))
     #
     # square root of Sigma for simulating field
@@ -111,7 +113,7 @@ sim.spatialProcess<- function(object, xp,  M = 1,
         # value of simulated field at observations
         h.data <- h[1:n]
         #
-        y.synthetic <- h.data + sqrt(sigma2/object$weights)*rnorm(n)
+        y.synthetic <- h.data + sqrt(tau2/object$weights)*rnorm(n)
         # predict at xp using these data
         # and subtract from 'true' value, 
         # note that true values of field have to be expanded in the
