@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2021 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 "summary.Krig" <- function(object, digits = 4, ...) {
     x <- object
     # lambda est may not be available if lambda has been supplied by user.
@@ -30,10 +31,10 @@
     summary <- list(call = x$call, num.observation = length(x$residuals), 
         enp = x$eff.df, nt = x$nt, df.drift = sum(x$ind.drift), 
         res.quantile = quantile(x$residuals, seq(0, 1, 0.25)), 
-        shat.MLE = x$shat.MLE, shat.GCV = x$shat.GCV, rhohat = x$rhohat, 
-        m = x$m, lambda = x$lambda, cost = x$cost, rho = x$rho, 
-        sigma2 = x$sigma2, num.uniq = length(x$yM), knot.model = x$knot.model, 
-        np = x$np, method = x$method, lambda.est = l.est, shat.pure.error = x$shat.pure.error, 
+        tauHat.MLE = x$tauHat.MLE, tauHat.GCV = x$tauHat.GCV, sigmahat = x$sigmahat, 
+        m = x$m, lambda = x$lambda, cost = x$cost, sigma = x$sigma, 
+        tau2 = x$tau2, num.uniq = length(x$yM), knot.model = x$knot.model, 
+        np = x$np, method = x$method, lambda.est = l.est, tauHat.pure.error = x$tauHat.pure.error, 
         args = x$args)
     class(summary) <- "summary.Krig"
     summary$covariance <- cor(x$fitted.values * sqrt(x$weights), 
