@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2021 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 
 "vgram" <- function(loc, y, id = NULL, d = NULL, lon.lat = FALSE, 
                     dmax = NULL, N = NULL, breaks = NULL, 
@@ -50,8 +51,8 @@
   # normalize columns to create correlogram, if necessary
   #
   if(type == "correlogram") {
-    sigma = apply(y, 2, sd, na.rm=TRUE)
-    y = sweep(y, 2, (1/sigma), FUN="*")
+    tau = apply(y, 2, sd, na.rm=TRUE)
+    y = sweep(y, 2, (1/tau), FUN="*")
   }
   
   # center the columns by their mean and get row means if y is a matrix
@@ -130,10 +131,10 @@ crossCoVGram = function(loc1, loc2, y1, y2, id = NULL, d = NULL, lon.lat = FALSE
   # normalize to create cross-correlogram, if necessary
   #
   if(type == "cross-correlogram") {
-    sigma1 = apply(y1Cntr, 2, sd, na.rm=TRUE)
-    sigma2 = apply(y2Cntr, 2, sd, na.rm=TRUE)
-    y1Cntr = sweep(y1Cntr, 2, 1/sigma1, FUN="*")
-    y2Cntr = sweep(y2Cntr, 2, 1/sigma2, FUN="*")
+    tau1 = apply(y1Cntr, 2, sd, na.rm=TRUE)
+    tau2 = apply(y2Cntr, 2, sd, na.rm=TRUE)
+    y1Cntr = sweep(y1Cntr, 2, 1/tau1, FUN="*")
+    y2Cntr = sweep(y2Cntr, 2, 1/tau2, FUN="*")
   }
   #
   # calculate covariance for the given points
