@@ -1,19 +1,24 @@
-# fields is a package for analysis of spatial data written for
-  # the R software environment .
-  # Copyright (C) 2018
-  # University Corporation for Atmospheric Research (UCAR)
-  # Contact: Douglas Nychka, nychka@ucar.edu,
-  # National Center for Atmospheric Research,
-  # PO Box 3000, Boulder, CO 80307-3000
-  #
-  # This program is free software; you can redistribute it and/or modify
-  # it under the terms of the GNU General Public License as published by
-  # the Free Software Foundation; either version 2 of the License, or
-  # (at your option) any later version.
-  # This program is distributed in the hope that it will be useful,
-  # but WITHOUT ANY WARRANTY; without even the implied warranty of
-  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  # GNU General Public License for more details.
+#
+# fields  is a package for analysis of spatial data written for
+# the R software environment.
+# Copyright (C) 2021 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with the R software environment if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 
 suppressMessages(library(fields))
 #
@@ -32,15 +37,15 @@ set.seed(123)
 x<- matrix( runif( 30), 15,2)
 Z<- matrix( rnorm(30), 15,2)
 y<- rnorm( 15)*.01 + 5*(x[,1]**3 +  (x[,2]-.5)**2) +  (Z[,1] +Z[,2])*.001
-knots<- x[1:5,]
 #weights<- runif(15)*10
 
 # first without knots compare default to fixed
 
-Krig( x,y,Z=Z, cov.function=Exp.cov, give.warnings=FALSE)-> out.new
-
-Krig( x,y,Z=Z, cov.function=Exp.cov,lambda=1)-> out.new2
+out.new<-  Krig( x,y,Z=Z, cov.function=Exp.cov, give.warnings=FALSE)-> out.new
 
+out.new2<- Krig( x,y,Z=Z, cov.function=Exp.cov,
+                 lambda=1)
+ 
 
 ##########
 ## compute test using linear algebra
@@ -86,98 +91,7 @@ test.for.zero( hold, hold3, tag="predict for null spatial" )
 
 hold<-T[,1:3]%*%temp.d[1:3]               
 test.for.zero( hold, hold4, tag="predict for null drift " )
-
-
-
-###knots case *****************************
-
-
-
-set.seed(123)
-x<- matrix( runif( 30), 15,2)
-Z<- matrix( rnorm(30), 15,2)
-y<- rnorm( 15)*.01 + 5*(x[,1]**3 +
-                           (x[,2]-.5)**2) +  (Z[,1] +Z[,2])*.001
-knots<- x[1:5,]
-weights<- runif(15)*10
-y[5] <- y[5] + 3 # avoids GCV warning 
-
-# compare to 
-Krig( x,y,Z=Z, knots=knots, cov.function=Exp.cov,weights=weights,
-verbose=FALSE, give.warnings=FALSE)-> out.new
-
-Krig( x,y,Z=Z, knots=knots, cov.function=Exp.cov,weights=weights, 
-          lambda=1)-> out.new2
-
-# compare to each other
-Krig.coef( out.new, lambda=1)-> look
-# test for d coefficients
-test.for.zero( out.new2$d, look$d, tag=" knots/weights fixed/default d coef")
-# test for c coefficents
-test.for.zero( out.new2$c, look$c, tag="knots/weights fixed/default c coef" )
-
-
-# compute test using linear algebra
-
-K<- Exp.cov( knots, knots)
-
-T<- cbind( rep(1,15), x, Z)
-X<- cbind( T, Exp.cov( x, knots))
-lambda<-1.0
-NN<- ncol( X)
-H<- matrix( 0, NN, NN)
-H[(1:5)+5, (1:5)+5] <- K
-
-c(   solve(t(X)%*%(weights*X) + lambda*H)%*% t(X)%*% (weights*y) )-> temp
-temp.c<- temp[6:10]
-temp.d<- temp[1:5]
-
-# test for d coefficients
-test.for.zero( out.new2$d, temp.d, tag=" knots d coef")
-# test for c coefficents
-test.for.zero( out.new2$c, temp.c, tag="knots c coef" )
-
-
-####### testing predict function 
-hold1<- predict( out.new2, x=x, Z=Z, y=y)
-hold2<- predict( out.new2, x=x, Z=Z, just.fixed=TRUE,y=y)
-hold3<- predict( out.new2, x=x, Z=Z, drop.Z=TRUE,y=y)
-hold4<- predict( out.new2, x=x, Z=Z, drop.Z=TRUE, just.fixed=TRUE,y=y)
-
-
-hold<- X%*% temp
-#  X%*% temp -  X[,4:5]%*% temp[c(4,5)]
-
-test.for.zero( hold, hold1, tag="knots predict for null" )
-
-hold<-T%*%temp.d
-test.for.zero( hold, hold2, tag="knots predict for null" )
-
-hold<-X%*%temp - X[,4:5] %*% temp[4:5]
-test.for.zero( hold, hold3, tag="knots predict w/o Z" )
-
-hold<-T[,1:3]%*%temp.d[1:3]
-test.for.zero( hold, hold4, tag="knots predict for drift" )
-
-######tests where coefficients  are recomputed from object
-hold1<- predict( out.new,y=y, lambda=1.0,  x=x, Z=Z)
-hold2<- predict( out.new,y=y, lambda=1.0, x=x, Z=Z, just.fixed=TRUE)
-hold3<- predict( out.new, y=y, lambda=1.0, x=x, Z=Z, drop.Z=TRUE)
-hold4<- predict( out.new, y=y, lambda=1.0, x=x, Z=Z, 
-                      drop.Z=TRUE, just.fixed=TRUE)
-
-hold<-X%*%temp
-test.for.zero( hold, hold1, tag="predict for null" )
-
-hold<-T%*%temp.d
-test.for.zero( hold, hold2, tag="predict for null" )
-
-hold<-X[,1:3] %*%temp.d[1:3] + X[,6:10] %*% temp.c
-test.for.zero( hold, hold3, tag="predict for null" )
-
-hold<-T[,1:3]%*%temp.d[1:3]               
-test.for.zero( hold, hold4, tag="predict for null" )
-
+#
 
 ####### tests using predict.se
  x<- ChicagoO3$x
@@ -238,45 +152,45 @@ tps.fit<-Tps( x,y, scale.type="unscaled", Z= Zcov)
 out<- tps.fit
 
 A<- Krig.Amatrix( tps.fit,x= xg, drop.Z=TRUE)
-Sigma<- out$rhohat*Rad.cov( out$x, out$x, p=2)
-S0<- out$rhohat*Rad.cov(xg, xg, p=2)
-S1<- out$rhohat*Rad.cov(out$x, xg, p=2)
+Sigma<- out$sigmahat*Rad.cov( out$x, out$x, p=2)
+S0<- out$sigmahat*Rad.cov(xg, xg, p=2)
+S1<- out$sigmahat*Rad.cov(out$x, xg, p=2)
 
 #yhat= Ay
 #var( f0 - yhat)=    var( f0) - 2 cov( f0,yhat)+  cov( yhat)
 
    look<- S0 - t(S1)%*% t(A) - A%*%S1 +
-       A%*% ( Sigma + diag(out$shat.MLE**2/out$weightsM))%*% t(A)
+       A%*% ( Sigma + diag(out$tauHat.MLE**2/out$weightsM))%*% t(A)
    look<- diag( look)
    test.for.zero(curv.var2 ,look,tag="SE w/o covariate")
 
 
 A<- Krig.Amatrix( tps.fit,x= xg, drop.Z=FALSE,Z=Zcov.grid)
 # see tps.fit$args for value of p
-Sigma<- out$rhohat*Rad.cov( out$x, out$x, p=2)
-S0<- out$rhohat*Rad.cov(xg, xg, p=2)
-S1<- out$rhohat*Rad.cov(out$x, xg, p=2)
+Sigma<- out$sigmahat*Rad.cov( out$x, out$x, p=2)
+S0<- out$sigmahat*Rad.cov(xg, xg, p=2)
+S1<- out$sigmahat*Rad.cov(out$x, xg, p=2)
 
 #yhat= Ay
 #var( f0 - yhat)=    var( f0) - 2 cov( f0,yhat)+  cov( yhat)
 
    look<- S0 - t(S1)%*% t(A) - A%*%S1 +
-       A%*% ( Sigma + diag(out$shat.MLE**2/out$weightsM))%*% t(A)
+       A%*% ( Sigma + diag(out$tauHat.MLE**2/out$weightsM))%*% t(A)
    look<- diag( look)
    test.for.zero(curv.var1 ,look,tag="SE with covariate")
 
 
 A<- Krig.Amatrix( tps.fit,x= xg, drop.Z=FALSE,Z=Zcov.grid, just.fixed=TRUE)
 # see tps.fit$args for value of p
-Sigma<- out$rhohat*Rad.cov( out$x, out$x, p=2)
-S0<- out$rhohat*Rad.cov(xg, xg, p=2)
-S1<- out$rhohat*Rad.cov(out$x, xg, p=2)
+Sigma<- out$sigmahat*Rad.cov( out$x, out$x, p=2)
+S0<- out$sigmahat*Rad.cov(xg, xg, p=2)
+S1<- out$sigmahat*Rad.cov(out$x, xg, p=2)
 
 #yhat= Ay
 #var( f0 - yhat)=    var( f0) - 2 cov( f0,yhat)+  cov( yhat)
 
    look<- S0 - t(S1)%*% t(A) - A%*%S1 +
-       A%*% ( Sigma + diag(out$shat.MLE**2/out$weightsM))%*% t(A)
+       A%*% ( Sigma + diag(out$tauHat.MLE**2/out$weightsM))%*% t(A)
    look<- diag( look)
    test.for.zero(curv.var3 ,look, tag="SE for fixed part")
 
