@@ -1,22 +1,27 @@
- # fields is a package for analysis of spatial data written for
-  # the R software environment .
-  # Copyright (C) 2017
-  # University Corporation for Atmospheric Research (UCAR)
-  # Contact: Douglas Nychka, nychka@ucar.edu,
-  # National Center for Atmospheric Research,
-  # PO Box 3000, Boulder, CO 80307-3000
-  #
-  # This program is free software; you can redistribute it and/or modify
-  # it under the terms of the GNU General Public License as published by
-  # the Free Software Foundation; either version 2 of the License, or
-  # (at your option) any later version.
-  # This program is distributed in the hope that it will be useful,
-  # but WITHOUT ANY WARRANTY; without even the implied warranty of
-  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  # GNU General Public License for more details.
+#
+# fields  is a package for analysis of spatial data written for
+# the R software environment.
+# Copyright (C) 2021 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with the R software environment if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 
 
-library(fields)
+suppressMessages(library(fields))
 #
 #
 #
@@ -82,7 +87,7 @@ test<- Krig.fgcv.model( lam=out.new$lambda, out.new)
 y0<- out.new$yM
 n0<- length(y0)
 # compare to 
-test2<- (1/n0)*sum(  (y0 - c(Alam0%*% y0))**2 *out.new$weightsM) / (1- sum(diag( Alam0))/n0)**2 + out.new$shat.pure.error**2
+test2<- (1/n0)*sum(  (y0 - c(Alam0%*% y0))**2 *out.new$weightsM) / (1- sum(diag( Alam0))/n0)**2 + out.new$tauHat.pure.error**2
 test.for.zero( test,test2,tag="GCV model")
 
 
@@ -94,7 +99,7 @@ data( ozone2)
 x<- ozone2$lon.lat
 y<- ozone2$y[16,]
 Tps( x,y)-> out
-gcv.Krig( out, tol=1e-10)-> out2
+KrigFindLambda( out, tol=1e-10)-> out2
 
 test.for.zero(out$lambda.est[1,-6], 
        out2$lambda.est[1,-6],tol=5e-4, tag="Tps/gcv for ozone2")
@@ -102,7 +107,7 @@ test.for.zero(out$lambda.est[1,-6],
 # try with "new" data (linear transform should give identical 
 # results for GCV eff df
 
-gcv.Krig( out, y=(11*out$y + 5), tol=1e-10 )-> out3
+KrigFindLambda( out, y=(11*out$y + 5), tol=1e-10 )-> out3
 
 test.for.zero(out2$lambda.est[1,2], 
        out3$lambda.est[1,2],tol=1e-6, tag="Tps/gcv for ozone2 new data")
